==> spring-cloud-contract-verifier-3.0.4-sources.jar: org/springframework/cloud/contract/verifier/util/xml/XmlToXPathsConverter.java <==
package org.springframework.cloud.contract.verifier.util.xml;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;
import static java.util.stream.Collectors.toList;
import static javax.xml.xpath.XPathConstants.NODESET;
import static org.apache.commons.lang3.StringUtils.isBlank;
import static org.w3c.dom.Node.ATTRIBUTE_NODE;
import static org.w3c.dom.Node.CDATA_SECTION_NODE;
import static org.w3c.dom.Node.COMMENT_NODE;
import static org.w3c.dom.Node.DOCUMENT_NODE;
import static org.w3c.dom.Node.DOCUMENT_TYPE_NODE;
import static org.w3c.dom.Node.NOTATION_NODE;
import static org.w3c.dom.Node.PROCESSING_INSTRUCTION_NODE;
import static org.w3c.dom.Node.TEXT_NODE;

public class XmlToXPathsConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static  java.lang.String buildXPath(java.util.List<org.w3c.dom.Node> nodes) { return (java.lang.String)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public static  java.lang.Object removeMatchingXPaths(java.lang.Object body, org.springframework.cloud.contract.spec.internal.BodyMatchers bodyMatchers) { return null;}
public static  java.lang.String retrieveValue(org.springframework.cloud.contract.spec.internal.BodyMatcher matcher, java.lang.Object body) { return (java.lang.String)null;}
public static  java.lang.String retrieveValueFromBody(java.lang.String path, java.lang.Object body) { return (java.lang.String)null;}
public static  java.util.List<org.springframework.cloud.contract.spec.internal.BodyMatcher> mapToMatchers(java.lang.Object xml) { return (java.util.List<org.springframework.cloud.contract.spec.internal.BodyMatcher>)null;}
public static  boolean isPathToDefaultXmlnsAttributeNode(org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath nodePath) { return false;}
public static  java.util.List<org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath> transformListEntries(java.util.List<java.util.List<org.w3c.dom.Node>> nodeLists) { return (java.util.List<org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath>)null;}
public static  java.lang.String buildXPath(java.util.List<org.w3c.dom.Node> nodes, int index) { return (java.lang.String)null;}
private static class NodePath
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public NodePath
(java.util.List<org.w3c.dom.Node> path, int index) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  java.util.List<org.w3c.dom.Node> getPath() { return (java.util.List<org.w3c.dom.Node>)null;}
public final  int getIndex() { return (int)0;}
public  java.util.List<org.w3c.dom.Node> fromChildToParents() { return (java.util.List<org.w3c.dom.Node>)null;}
}
private static class PathOccurrenceCounter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public PathOccurrenceCounter
(java.util.List<org.w3c.dom.Node> path) {}
@groovy.transform.Generated() @groovy.transform.Internal() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  java.lang.Object getProperty(java.lang.String property) { return null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setProperty(java.lang.String property, java.lang.Object value) { }
public final  java.util.List<org.w3c.dom.Node> getPath() { return (java.util.List<org.w3c.dom.Node>)null;}
public  int getCounter() { return (int)0;}
public  void setCounter(int value) { }
}
}

==> spring-cloud-contract-verifier-3.1.3-sources.jar: org/springframework/cloud/contract/verifier/util/xml/XmlToXPathsConverter.java <==
package org.springframework.cloud.contract.verifier.util.xml;
import java.lang.*;
import java.util.*;
import java.io.*;
import java.net.*;
import groovy.lang.*;
import groovy.util.*;
import static java.util.stream.Collectors.toList;
import static javax.xml.xpath.XPathConstants.NODESET;
import static org.apache.commons.lang3.StringUtils.isBlank;
import static org.w3c.dom.Node.ATTRIBUTE_NODE;
import static org.w3c.dom.Node.CDATA_SECTION_NODE;
import static org.w3c.dom.Node.COMMENT_NODE;
import static org.w3c.dom.Node.DOCUMENT_NODE;
import static org.w3c.dom.Node.DOCUMENT_TYPE_NODE;
import static org.w3c.dom.Node.NOTATION_NODE;
import static org.w3c.dom.Node.PROCESSING_INSTRUCTION_NODE;
import static org.w3c.dom.Node.TEXT_NODE;

public class XmlToXPathsConverter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public static  java.lang.String buildXPath(java.util.List<org.w3c.dom.Node> nodes) { return (java.lang.String)null;}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public static  java.lang.Object removeMatchingXPaths(java.lang.Object body, org.springframework.cloud.contract.spec.internal.BodyMatchers bodyMatchers) { return (java.lang.Object)null;}
public static  java.lang.String retrieveValue(org.springframework.cloud.contract.spec.internal.BodyMatcher matcher, java.lang.Object body) { return (java.lang.String)null;}
public static  java.lang.String retrieveValueFromBody(java.lang.String path, java.lang.Object body) { return (java.lang.String)null;}
public static  java.util.List<org.springframework.cloud.contract.spec.internal.BodyMatcher> mapToMatchers(java.lang.Object xml) { return (java.util.List<org.springframework.cloud.contract.spec.internal.BodyMatcher>)null;}
public static  boolean isPathToDefaultXmlnsAttributeNode(org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath nodePath) { return false;}
public static  java.util.List<org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath> transformListEntries(java.util.List<java.util.List<org.w3c.dom.Node>> nodeLists) { return (java.util.List<org.springframework.cloud.contract.verifier.util.xml.XmlToXPathsConverter.NodePath>)null;}
public static  java.lang.String buildXPath(java.util.List<org.w3c.dom.Node> nodes, int index) { return (java.lang.String)null;}
private static class NodePath
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public NodePath
(java.util.List<org.w3c.dom.Node> path, int index) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public final  java.util.List<org.w3c.dom.Node> getPath() { return (java.util.List<org.w3c.dom.Node>)null;}
public final  int getIndex() { return (int)0;}
public  java.util.List<org.w3c.dom.Node> fromChildToParents() { return (java.util.List<org.w3c.dom.Node>)null;}
}
private static class PathOccurrenceCounter
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
;
public PathOccurrenceCounter
(java.util.List<org.w3c.dom.Node> path) {}
@groovy.transform.Generated() @groovy.transform.Internal() @java.beans.Transient() public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
@groovy.transform.Generated() @groovy.transform.Internal() public  void setMetaClass(groovy.lang.MetaClass mc) { }
public final  java.util.List<org.w3c.dom.Node> getPath() { return (java.util.List<org.w3c.dom.Node>)null;}
public  int getCounter() { return (int)0;}
public  void setCounter(int value) { }
}
}
